@@ -7,6 +7,7 @@ from django.utils import unittest
 from mongoengine import connect, connection
 from mongoengine.django import tests
 
+
 class MongoEngineTestSuiteRunner(simple.DjangoTestSuiteRunner):
     """
     It is the same as in DjangoTestSuiteRunner, but without relational databases.
@@ -48,10 +49,11 @@ class MongoEngineTestSuiteRunner(simple.DjangoTestSuiteRunner):
     def teardown_databases(self, old_config, **kwargs):
         connection.get_connection().drop_database(self.db_name)
 
+
 class MongoEngineTestCase(tests.MongoTestCase):
     """
     A bugfixed version, see this `pull request`_.
-    
+
     .. _pull request: https://github.com/hmarr/mongoengine/pull/506
     """
 
@@ -63,18 +65,20 @@ class MongoEngineTestCase(tests.MongoTestCase):
         self.db = connection.get_db()
         super(MongoEngineTestCase, self)._post_teardown()
 
+
 # We also patch Django so that it supports PATCH requests (used by Tastypie)
 # Taken from https://code.djangoproject.com/attachment/ticket/17797/django-test-client-PATCH.patch
 
-def requestfactory_patch(self, path, data={}, content_type=client.MULTIPART_CONTENT, **extra):
+def requestfactory_patch(self, path, data=None, content_type=client.MULTIPART_CONTENT, **extra):
     """
     Construct a PATCH request.
     """
-    
+
+    data = data or {}
     patch_data = self._encode_data(data, content_type)
 
     parsed = urlparse.urlparse(path)
-    r = {
+    request = {
         'CONTENT_LENGTH': len(patch_data),
         'CONTENT_TYPE': content_type,
         'PATH_INFO': self._get_path(parsed),
@@ -82,14 +86,17 @@ def requestfactory_patch(self, path, data={}, content_type=client.MULTIPART_CONT
         'REQUEST_METHOD': 'PATCH',
         'wsgi.input': client.FakePayload(patch_data),
     }
-    r.update(extra)
-    return self.request(**r)
+    request.update(extra)
+    return self.request(**request)
 
-def client_patch(self, path, data={}, content_type=client.MULTIPART_CONTENT, follow=False, **extra):
+
+def client_patch(self, path, data=None, content_type=client.MULTIPART_CONTENT, follow=False, **extra):
     """
     Send a resource to the server using PATCH.
     """
-    response = super(Client, self).patch(path, data=data, content_type=content_type, **extra)
+
+    data = data or {}
+    response = super(client.Client, self).patch(path, data=data, content_type=content_type, **extra)
     if follow:
         response = self._handle_redirects(response, **extra)
     return response
